"use client";

import "@fontsource-variable/fira-code";
import { createHighlighter } from "shiki";
import type { editor } from "monaco-editor";
import { shikiToMonaco } from "@shikijs/monaco";
import { useEffect, useRef, useMemo } from "react";
import { useCodeEditorStore } from "@/store/codeEditorStore";
import MonacoEditor, { type Monaco } from "@monaco-editor/react";

const ADDITIONAL_THEMES = [
  "andromeeda",
  "aurora-x",
  "ayu-dark",
  "catppuccin-frappe",
  "catppuccin-latte",
  "catppuccin-macchiato",
  "catppuccin-mocha",
  "dark-plus",
  "dracula",
  "dracula-soft",
  "one-dark-pro",
  "vitesse-dark",
  "vitesse-light",
];

const ADDITIONAL_LANGUAGES = ["c", "java"] as const satisfies Parameters<
  typeof createHighlighter
>[0]["langs"];

export function CodeEditor() {
  const monacoRef = useRef<Monaco | null>(null);
  const editorRef = useRef<editor.IStandaloneCodeEditor | null>(null);
  const { lang, theme, value, isLigature } = useCodeEditorStore();

  useEffect(() => {
    if (monacoRef.current && editorRef.current) {
      monacoRef.current.editor.setTheme(theme);
    }
  }, [theme]);

  const options = useMemo(
    () => ({
      minimap: { enabled: false },
      fontSize: 14,
      fontFamily: "Fira Code Variable, monospace",
      tabSize: 4,
      showFoldingControls: "always" as const,
      fontLigatures: isLigature,
      automaticLayout: true,
      guides: {
        bracketPairs: true,
        indentation: true,
      },
    }),
    [isLigature]
  );

  const handleEditorMount = async (
    editor: editor.IStandaloneCodeEditor,
    monaco: Monaco
  ) => {
    editorRef.current = editor;
    monacoRef.current = monaco;

    for (const lang of ADDITIONAL_LANGUAGES) {
      monacoRef.current?.languages.register({ id: lang });
    }

    const highlighter = await createHighlighter({
      themes: ADDITIONAL_THEMES,
      langs: ADDITIONAL_LANGUAGES,
    });

    shikiToMonaco(highlighter, monacoRef.current);
  };

  return (
    <MonacoEditor
      language={lang}
      theme={theme}
      options={options}
      value={value}
      onMount={handleEditorMount}
    />
  );
}
