import {
  SidebarInset,
  SidebarProvider,
  SidebarTrigger,
} from "@/components/ui/sidebar";
import { SessionProvider } from "next-auth/react";
import { Separator } from "@/components/ui/separator";
import ThemeSelector from "./components/theme-selector";
import { ModeSwitcher } from "@/components/mode-switcher";
import LanguageSwitcher from "@/components/language-switcher";
import LigaturesCheckbox from "./components/ligatures-checkbox";
import { PlaygroundSidebar } from "@/app/playground/components/playground-sidebar";

export default function PlaygroundLayout({
  children,
}: Readonly<{ children: React.ReactNode }>) {
  return (
    <SessionProvider>
      <SidebarProvider>
        <PlaygroundSidebar />
        <SidebarInset>
          <header className="flex h-14 shrink-0 items-center gap-2">
            <div className="flex flex-1 items-center gap-2 px-3">
              <SidebarTrigger />
              <ModeSwitcher />
              <Separator orientation="vertical" className="mr-2 h-4" />
              <ThemeSelector />
              <LigaturesCheckbox />
            </div>
            <div className="ml-auto px-3">
              <LanguageSwitcher />
            </div>
          </header>
          {children}
        </SidebarInset>
      </SidebarProvider>
    </SessionProvider>
  );
}
